@@ -34,6 +34,10 @@ class Articles:
         req = self._con.get(url=self._url_get_articles+'/'+str(p_article))
         return req.json()
 
+    def get_article_de_congelador(self):
+        req = self._con.get(url=self._url_get_articles + '?congelat=true')
+        return req.json()
+
     def get_article_by_ean(self, p_ean13_article: str):
         req = self._con.get(url=self._url_get_articles+'?ean13_article='+str(p_ean13_article))
         return req.json()
